package CPAN::Test::Dummy::SCO::Lacks;
use strict;
use warnings;

=head1 NAME

CPAN::Test::Dummy::SCO::Lacks - some stuff is not here

=head1 DESCRIPTION

See L<search.cpan.org clone project|http://perlmaven.com/search-cpan-org>.

=cut

our $VERSION = '0.01';


1;

